LayerContainerReader
====================

.. currentmodule:: wwt_data_formats.layers

.. autoclass:: LayerContainerReader
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~LayerContainerReader.layers

   .. rubric:: Methods Summary

   .. autosummary::

      ~LayerContainerReader.close
      ~LayerContainerReader.from_file
      ~LayerContainerReader.read_layer_file

   .. rubric:: Attributes Documentation

   .. autoattribute:: layers

   .. rubric:: Methods Documentation

   .. automethod:: close
   .. automethod:: from_file
   .. automethod:: read_layer_file
